@@ -21,7 +21,12 @@ import aws_cdk.core._jsii
 import aws_cdk.cx_api._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-apigateway", "1.49.0", __name__[0:-6], "aws-apigateway@1.49.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-apigateway",
+    "1.55.0",
+    __name__[0:-6],
+    "aws-apigateway@1.55.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
